@@ -37,10 +37,13 @@ github_document <- function(toc = FALSE,
     pkg_file_arg("rmarkdown/templates/github_document/resources/default.md")
   )
 
-
   pandoc2 <- pandoc2.0()
   # use md_document as base
-  variant <- if (pandoc2) "gfm" else "markdown_github"
+  if (pandoc2) {
+    variant <-  "gfm"
+  } else {
+    variant <- "markdown_github"
+  }
   if (!hard_line_breaks) variant <- paste0(variant, "-hard_line_breaks")
 
   format <- md_document(
@@ -48,7 +51,7 @@ github_document <- function(toc = FALSE,
     number_sections = number_sections, fig_width = fig_width,
     fig_height = fig_height, dev = dev, df_print = df_print,
     includes = includes, md_extensions = md_extensions,
-    pandoc_args = pandoc_args
+    pandoc_args = c("--atx-headers", pandoc_args)
   )
 
   # add a post processor for generating a preview if requested
@@ -93,3 +96,28 @@ github_document <- function(toc = FALSE,
 
   format  # return format
 }
+
+# explicit definition of gfm_format -- not currently used b/c it didn't
+# yield different about that 'gfm' w/ pandoc 2.11. keeping in the source
+# code for now in case we need to use it for another workaround.
+gfm_format <- function() {
+  paste0("markdown_strict",
+   # commonmark
+   "+raw_html",
+   "+all_symbols_escapable",
+   "+backtick_code_blocks",
+   "+fenced_code_blocks",
+   "+space_in_atx_header",
+   "+intraword_underscores",
+   "+lists_without_preceding_blankline",
+   "+shortcut_reference_links",
+   # gfm extensions
+   "+auto_identifiers",
+   "+autolink_bare_uris",
+   "+emoji",
+   "+gfm_auto_identifiers",
+   "+pipe_tables",
+   "+strikeout",
+   "+task_lists"
+  )
+}
