@@ -125,6 +125,15 @@ html_dependency_navigation <- function(code_menu, source_embed) {
                  script = script)
 }
 
+html_dependency_anchor_sections <- function() {
+
+  htmlDependency(name = "anchor-sections",
+                 version = "1.0",
+                 src = pkg_file("rmd/h/anchor-sections"),
+                 script = "anchor-sections.js",
+                 stylesheet = "anchor-sections.css")
+}
+
 # analyze navbar html source for icon dependencies
 navbar_icon_dependencies <- function(navbar) {
 
@@ -145,8 +154,8 @@ navbar_icon_dependencies <- function(navbar) {
   html_dependencies_fonts("fa fa" %in% libs, "ion ion" %in% libs)
 }
 
-# utilty function to return a list of font dependencies based
-# whether we are including font_awesome and/or iconicons
+# utility function to return a list of font dependencies based
+# whether we are including font_awesome and/or ionicons
 html_dependencies_fonts <- function(font_awesome, ionicons) {
   deps <- list()
   if (font_awesome)
