@@ -2,7 +2,7 @@
 #'
 #' Format for converting from R Markdown to an ODT document.
 #'
-#' See the \href{https://rmarkdown.rstudio.com/odt_document_format.html}{online
+#' See the \href{https://bookdown.org/yihui/rmarkdown/opendocument-text-document.html}{online
 #' documentation} for additional details on using the \code{odt_document} format.
 #'
 #' R Markdown documents can have optional metadata that is used to generate a
@@ -31,7 +31,8 @@
 #' render("input.Rmd", odt_document(highlight = "zenburn"))
 #' }
 #' @export
-odt_document <- function(fig_width = 5,
+odt_document <- function(number_sections = FALSE,
+                         fig_width = 5,
                          fig_height = 4,
                          fig_caption = TRUE,
                          template = "default",
@@ -60,19 +61,33 @@ odt_document <- function(fig_width = 5,
   args <- c(args, includes_to_pandoc_args(includes))
 
   # reference odt
-  if (!is.null(reference_odt) && !identical(reference_odt, "default")) {
-    args <- c(args, reference_doc_arg("odt"), pandoc_path_arg(reference_odt))
-  }
+  args <- c(args, reference_doc_args("odt", reference_odt))
 
   # pandoc args
   args <- c(args, pandoc_args)
 
+  saved_files_dir <- NULL
+  pre_processor <- function(metadata, input_file, runtime, knit_meta, files_dir, output_dir) {
+    saved_files_dir <<- files_dir
+    NULL
+  }
+
+  intermediates_generator <- function(...) {
+    reference_intermediates_generator(saved_files_dir, ..., reference_odt)
+  }
+
   # return output format
   output_format(
     knitr = knitr,
-    pandoc = pandoc_options(to = "odt",
-                            from = from_rmarkdown(fig_caption, md_extensions),
-                            args = args),
-    keep_md = keep_md
+    pandoc = pandoc_options(
+      to = "odt",
+      from = from_rmarkdown(fig_caption, md_extensions),
+      args = args,
+      lua_filters = pkg_file_lua(
+        c("pagebreak.lua", if (number_sections) "number-sections.lua"))
+    ),
+    keep_md = keep_md,
+    pre_processor = pre_processor,
+    intermediates_generator = intermediates_generator
   )
 }
